# happy-simulator

[![PyPI](https://img.shields.io/pypi/v/happysim)](https://pypi.org/project/happysim/)
[![Tests](https://github.com/adamfilli/happy-simulator/actions/workflows/tests.yml/badge.svg)](https://github.com/adamfilli/happy-simulator/actions/workflows/tests.yml)
[![Docs](https://github.com/adamfilli/happy-simulator/actions/workflows/docs.yml/badge.svg)](https://adamfilli.github.io/happy-simulator/)

**** ALPHA ** Still in active development, large changes are expected.

A discrete-event simulation library with a focus on distributed systems.

https://adamfillion.com/posts/simulation-enhanced-reasoning/

## Installation

```bash
# Clone the repository
git clone https://github.com/adamfilli/happy-simulator.git
cd happy-simulator

# Create and activate a virtual environment (Windows PowerShell)
python -m venv .venv
.\.venv\Scripts\Activate.ps1

# Install in development mode
pip install -e .

# Install with development dependencies
pip install -e ".[dev]"
```
